@@ -168,6 +168,16 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         subCamBehavior.setDefaultCameraRot(rot);
     }
 
+    @Override
+    public void setDefaultCameraRev(double x,double y,double z) {
+        subCamBehavior.setDefaultCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setDefaultCameraRev(Vector3d rev) {
+        subCamBehavior.setDefaultCameraRev(rev);
+    }
+
     @Override
     public void setDefaultCameraScale(double s) {
         subCamBehavior.setDefaultCameraScale(s);
@@ -328,6 +338,56 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         return subCamBehavior.getCameraTargetRot();
     }
 
+    @Override
+    public void setCameraRev(double x,double y,double z) {
+        subCamBehavior.setCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setCameraRev(Vector3d rev) {
+        subCamBehavior.setCameraRev(rev);
+    }
+
+    @Override
+    public void setCameraRevImmediately(double x,double y,double z) {
+        subCamBehavior.setCameraRevImmediately(x,y,z);
+    }
+
+    @Override
+    public void setCameraRevImmediately(Vector3d rev) {
+        subCamBehavior.setCameraRevImmediately(rev);
+    }
+
+    @Override
+    public void mulCameraRev(double x,double y,double z) {
+        subCamBehavior.mulCameraRev(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRev(Vector3d rev) {
+        subCamBehavior.mulCameraRev(rev);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(double x,double y,double z) {
+        subCamBehavior.mulCameraRevImmediately(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev) {
+        subCamBehavior.setCameraRevImmediately(rev);
+    }
+
+    @Override
+    public Vector3d getCameraRev() {
+        return subCamBehavior.getCameraRev();
+    }
+
+    @Override
+    public Vector3d getCameraTargetRev() {
+        return subCamBehavior.getCameraTargetRev();
+    }
+
     @Override
     public void setCameraScale(double s) {
         subCamBehavior.setCameraScale(s);
@@ -1575,6 +1635,116 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         return null;
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setCameraRev(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setCameraRev(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setCameraRevImmediately(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setCameraRevImmediately(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRev(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRev(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRevImmediately(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraRev(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraTargetRev(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1686,6 +1856,28 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setDefaultCameraRev(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setDefaultCameraRev(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1703,7 +1895,7 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
      * 後のバージョンでは廃止する予定です。
      */
     @Override
-    public void setNavigationMode(NaviMode m, int scene,Object...params) {
+    public void setNavigationMode(int scene,NaviMode m,Object...params) {
         // TODO Version3系列ではこのメソッドが削除できるようにすべし。
         
     }
