@@ -272,6 +272,20 @@ class Scene implements Component2DContainerInterface {
         defaultQ = Util.euler2quat(rot);
     }
 
+    /**
+     * カメラのデフォルトの回転を指定します。
+     */
+    public void setDefaultCameraRev(double x,double y,double z) {
+        defaultQ = Util.euler2quat(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z);
+    }
+
+    /**
+     * カメラのデフォルトの回転を指定します。
+     */
+    public void setDefaultCameraRev(Vector3d rot) {
+        defaultQ = Util.euler2quat(Math.PI/180.0*rot.y,Math.PI/180.0*rot.x,Math.PI/180.0*rot.z);
+    }
+
     /**
      * カメラのデフォルトの拡大率を指定します。
      */
